# v.DEVELOPMENT

> [!NOTE]
> **[CHANGELOG.md is archived, from now on version-logs are at releases](https://github.com/GiorgosXou/untappdscr/releases)**


# v.1.0.3
* **FIXED:** `install_requires=['BeautifulSoup4', 'dacite']`
* **FIXED:** [Solve bad request issues](https://github.com/GiorgosXou/untappdscr/issues/1)
* **ADDED:** ^ `max_retries` `retry_delay` 

# v.1.0.1
* **FIXED:** typo `Scrapper` to `Scraper`

# v.1.0.0
* This is the first version, no change.
